@@ -24,8 +24,6 @@ test_that("Result with default parameters is tbl_df with required columns",{
   expect_equal(comment(data), "comment")
   expect_identical(nrow(cf), 24L)
   expect_identical(unique(cf$diff_group), c("a", "b", "c"))
-  print(unique(data$group))
-  print(unique(cf$group))
   expect_equal(unique(cf$group),
      c("liquid_normal", "solid_normal", "solid_patient"))
 })
